# Consistency Models

Understanding consistency is critical in distributed systems.

## Strong Consistency

All nodes see the same data at the same time.

## Eventual Consistency

Nodes will eventually converge to the same state.

## CAP Theorem

You can only guarantee two of three: Consistency, Availability, Partition tolerance.
